@@ -3,7 +3,18 @@ use napi::bindgen_prelude::*;
 use napi_derive::napi;
 
 use super::NapiConfig;
-use crate::doc::JsDoc;
+use crate::doc::{JsDoc, Wrapper};
+use ast_grep_core::source::Content;
+
+#[napi(object)]
+pub struct Edit {
+  /// The position of the edit
+  pub position: u32,
+  /// The length of the text to be deleted
+  pub deleted_length: u32,
+  /// The text to be inserted
+  pub inserted_text: String,
+}
 
 #[napi(object)]
 pub struct Pos {
@@ -294,6 +305,45 @@ impl SgNode {
   }
 }
 
+/// Edit API
+#[napi]
+impl SgNode {
+  #[napi]
+  pub fn replace(&self, text: String) -> Edit {
+    let byte_range = self.inner.range();
+    // the text is u16, need to convert to JS str length
+    Edit {
+      position: (byte_range.start / 2) as u32,
+      deleted_length: (byte_range.len() / 2) as u32,
+      inserted_text: text,
+    }
+  }
+
+  #[napi]
+  pub fn commit_edits(&self, mut edits: Vec<Edit>) -> String {
+    edits.sort_by_key(|edit| edit.position);
+    let mut new_content = Vec::new();
+    let text = self.text();
+    let old_content = Wrapper::decode_str(&text);
+    let offset = self.inner.range().start / 2;
+    let mut start = 0;
+    for diff in edits {
+      let pos = diff.position as usize - offset;
+      // skip overlapping edits
+      if start > pos {
+        continue;
+      }
+      new_content.extend(&old_content[start..pos]);
+      let bytes = Wrapper::decode_str(&diff.inserted_text);
+      new_content.extend(&*bytes);
+      start = pos + diff.deleted_length as usize;
+    }
+    // add trailing statements
+    new_content.extend(&old_content[start..]);
+    Wrapper::encode_bytes(&new_content).to_string()
+  }
+}
+
 /// Represents the parsed tree of code.
 #[napi]
 pub struct SgRoot(pub(super) AstGrep<JsDoc>, pub(super) String);
